#from django.db import models
from django.contrib.admin.filterspecs import DateFieldFilterSpec
from django.utils.translation import ugettext as _
from django.utils.html import escape
from django.utils.safestring import mark_safe
from django.utils.encoding import iri_to_uri
from django.conf import settings

class ExpenseDateFilterSpec(DateFieldFilterSpec):
    """
    A custom filter spec for the date field.

    It list all the available months, years of the Expenses objects.
    """

    def __init__(self, f, request, params, model, model_admin,
                 field_path=None):

        super(ExpenseDateFilterSpec, self).__init__(f, request, params, model,
                                                  model_admin)

        self.links = [(_('Any date'), {}),]

        
        months = model.objects.get_months()
        for m in months:
            self.links.append(
                (m.strftime("%Y. %B"),
                 {'%s__year' % self.field.name: str(m.year),
                  '%s__month' % self.field.name: str(m.month)}))

        years = model.objects.get_years()
        for y in years:
            self.links.append(
                (y.strftime("%Y. total"),
                 {'%s__year' % self.field.name: str(y.year)}))
